==> pacman-2.091.tar.gz: pacman-2.091/src/unix_base.py <==

import sys,os,string,commands

version = '2.091'

def phas(d,x):
	if d.count(x)>0: 
		return 1
	else:
		return 0

def python2():
	if sys.version[0]=='2':
		return 1
	else:
		return 0

def shx(str):
	if   shell()=='sh':
		return string.replace(str,'SHELL','sh')
	elif shell()=='csh':
		return string.replace(str,'SHELL','csh')
	else:
		if string.find(str,'SHELL')==-1:
			return str
		else:
			print 'Unknown unix shell.'
			sys.exit()

def shell():
	if os.environ.has_key('SHELL'):
		if   os.environ['SHELL'] == '/bin/csh':   sh = 'csh'
		elif os.environ['SHELL'] == '/bin/sh':    sh = 'sh'
		elif os.environ['SHELL'] == '/bin/tcsh':  sh = 'csh'
		elif os.environ['SHELL'] == '/bin/bash':  sh = 'sh'
		elif os.environ['SHELL'] == '/bin/bash2': sh = 'sh'
		elif os.environ['SHELL'] == '/bin/bsh':   sh = 'sh'
		elif os.environ['SHELL'] == '/bin/ash':   sh = 'sh'
		else:
			sh = ''
	else:
		sh = ''
	return sh

def qInpath(com):
	if python2():
		t1,t2,t3 = os.popen3('which '+com)
		return t3.readline()==''
	else:
		return os.system('which '+com) == 0

def launchbrowser(file):
	if    switch('mozilla'):
		os.system('mozilla '+file+' &')
	elif  switch('netscape'):
		os.system('netscape file:'+file+' &')
	elif  switch('lynx'):
		os.system('lynx '+file)
	elif    qInpath('mozilla'):
		os.system('mozilla '+file+' &')
	elif  qInpath('netscape'):
		os.system('netscape file:'+file+' &')
	elif  qInpath('lynx'):
		os.system('lynx '+file)
	else:
		print "Can''t find any web browser [mozilla/netscape/lynx] in path."
		sys.exit()		
	
#
#  this is for Python 2.0
#
#params   = [ arg for arg in sys.argv if not arg[0:1] == '-' and not arg[-6:] == 'pacman' ]
#switches = [ arg for arg in sys.argv if     arg[0:1] == '-' ]

def absloc(base,root,file):
	if len(file)<2:
		return fncat(base,fncat(root,file))
	elif file[0]=='|' and file[-1]=='|':
		return file[1:-1]
#		return fncat(base,file[1:-1])
	else:
		return fncat(base,fncat(root,file))

def qswitch(x): return     x[0:1]=='-' 
def qparam (x): return not x[0:1]=='-' and not x[-6:]=='pacman'

params   = filter(qparam,   sys.argv)
switches = filter(qswitch,  sys.argv)

def switchpar(sw):
	for s in switches:
		if s[:string.find(s,':')]=='-'+sw:
			return 1,s[string.find(s,':')+1:]
	return 0,''

def param(i):
	if i < 0: 
		print 'Hard error.'
		sys.exit()
	if i>len(params): return ('')
	else:             return (params[i])
	
def switch(arg):
	if switches.count('-'+arg)>0: return 1
	else:                         return 0	
		
verbose = switch('v') or switch('verbose')
		
def ask_to_execute(command):
	if switch('ask'):
		while 1:
			answer = raw_input('OK to execute: ['+command+'] (y or n)? ')
			if answer == 'y' or answer == 'n': break
		if answer=='y':
#			os.system(command)
#			return 1
			return try_to_execute(command)
		else:
			print '['+command+'] not executed.'
			sys.exit()
			return 0
	else:
#		os.system(command)
#		return 1
		return try_to_execute(command)
		
def ask_to_execute_cd(cddir,command):
#	os.system('cd '+cddir)
	i = ask_to_execute('cd '+cddir+'; '+command)
#	os.system('cd ..')
	return i
		
def try_to_execute(command):
	command2 = string.replace(command,'source ',fncat(os.environ['PACMAN'],'sourcerer.sh '))
	if verbose: print 'Executing ['+command2+']...'
	i = os.system(command2)
	if i==0: return 1
	else:    return 0

def is_root():
	pipe = os.popen('whoami')
	user = pipe.read()
	del pipe
	if user[:4] == 'root' or switch('rootpretend'): return 1
	else:                  return 0
	
def username():
	pipe = os.popen('whoami')
	user = pipe.read()
	del pipe
	return (user[:-1])

def put_in_path(root,file,syslocation):
	if is_root():
		if ask_to_execute('cp '+root+'/'+file+' '+syslocation): path = syslocation
		else: path = os.getcwd()+'/'+root
	else:
		path = os.getcwd()+'/'+root
	return (path)

def fncat(a,b):
	if a=='':
		return b
	else:
		if a[len(a)-1]=='/':
			if b=='':
				return (a[:-1])
			else:
				return (a+b)
		else:
			return (a+'/'+b)
			
def tail(str,t):
	found = 0
	if len(str)>= len(t):
		if str[len(str)-len(t):len(str)]==t:
			found = 1
	return found
#
#def yesno(s):
#	if    s == 1: return ('yes')
#	elif  s == 0: return ('no')
#	else:
#		print 'Unexpected argument to yesno.'
#		sys.exit()
#		
def yesdash(s):
	if    s >= 1: return ('yes')
	elif  s == 0: return ('-')
	else:
		print 'Unexpected argument to yesdash.'
		print s
		sys.exit()

def envFile(env,file):
	if os.environ.has_key(env):
		return fncat(os.environ[env],file)
	else:
		print '** Environment variable ['+env+'] is not defined.'
		sys.exit()
		
def envval(env):
	if os.environ.has_key(env): return os.environ[env]
	else: return ''

def substr(sub,base):
	for i in range(len(base)):
		if sub==base[i:i+len(sub)]: return 1
	return 0

def process_on(process):
	psf = os.popen('ps -edalf').readlines()
	l = len(process)
	for line in psf:
		if process == line[len(line)-1-l:len(line)-1]: return 1
	return 0
	
def rpm_installed(rpm_name):
	return (commands.getoutput('rpm -q '+rpm_name)==rpm_name)
	
def yesno(message):
	while 1:
		answer = raw_input(message+' (y or n): ')
		if answer == 'y' or answer == 'yes' or answer == 'n' or answer == 'no': break
	if answer == 'y' or answer == 'yes': return 1
	return 0
	
def rpm_replace(rpm_name):
	if rpm_installed(rpm_name): 
		if switch('force-rpm'):
			return 1
		elif yesno('Package ['+rpm_name+'] is already installed.  Do you want to replace it?'):
			return 1
		else:
			return 0
	else:
		return 0
		
def deWhite(s):
	ss = string.strip(s)
	return ss

==> pacman-2.112.tar.gz: pacman-2.112/src/unix_base.py <==

import sys,os,string,commands,pwd

version = '2.112'

def phas(d,x):
	if d.count(x)>0: 
		return 1
	else:
		return 0

def python2():
	if sys.version[0]=='2':
		return 1
	else:
		return 0

def shx(str):
	if   shell()=='sh':
		return string.replace(str,'SHELL','sh')
	elif shell()=='csh':
		return string.replace(str,'SHELL','csh')
	else:
		if string.find(str,'SHELL')==-1:
			return str
		else:
			print 'Unknown unix shell.'
			sys.exit()

def shell():
	if os.environ.has_key('SHELL'):
		if   os.environ['SHELL'] == '/bin/csh':   sh = 'csh'
		elif os.environ['SHELL'] == '/bin/sh':    sh = 'sh'
		elif os.environ['SHELL'] == '/bin/tcsh':  sh = 'csh'
		elif os.environ['SHELL'] == '/bin/bash':  sh = 'sh'
		elif os.environ['SHELL'] == '/bin/bash2': sh = 'sh'
		elif os.environ['SHELL'] == '/bin/bsh':   sh = 'sh'
		elif os.environ['SHELL'] == '/bin/ash':   sh = 'sh'
		else:
			sh = ''
	else:
		sh = ''
	return sh

def qInpath(com):
	if python2():
		t1,t2,t3 = os.popen3('which '+com)
		return t3.readline()==''
	else:
		return os.system('which '+com) == 0

def launchbrowser(file):
	if    switch('mozilla'):
		os.system('mozilla '+file+' &')
	elif  switch('netscape'):
		os.system('netscape file:'+file+' &')
	elif  switch('lynx'):
		os.system('lynx '+file)
	elif    qInpath('mozilla'):
		os.system('mozilla '+file+' &')
	elif  qInpath('netscape'):
		os.system('netscape file:'+file+' &')
	elif  qInpath('lynx'):
		os.system('lynx '+file)
	else:
		print "Can''t find any web browser [mozilla/netscape/lynx] in path."
		sys.exit()		
	
#
#  this is for Python 2.0
#
#params   = [ arg for arg in sys.argv if not arg[0:1] == '-' and not arg[-6:] == 'pacman' ]
#switches = [ arg for arg in sys.argv if     arg[0:1] == '-' ]

def absloc(base,root,file):
	if len(file)<2:
		return fncat(base,fncat(root,file))
	elif file[0]=='|' and file[-1]=='|':
		return file[1:-1]
#		return fncat(base,file[1:-1])
	else:
		return fncat(base,fncat(root,file))

def qswitch(x): return     x[0:1]=='-' 
def qparam (x): return not x[0:1]=='-' and not x[-6:]=='pacman'

params   = filter(qparam,   sys.argv)
switches = filter(qswitch,  sys.argv)

def switchpar(sw):
	for s in switches:
		if s[:string.find(s,':')]=='-'+sw:
			return 1,s[string.find(s,':')+1:]
	return 0,''

def param(i):
	if i < 0: 
		print 'Hard error.'
		sys.exit()
	if i>len(params): return ('')
	else:             return (params[i])
	
def switch(arg):
	if switches.count('-'+arg)>0: return 1
	else:                         return 0	
		
verbose = switch('v') or switch('verbose')
		
def ask_to_execute(command):
	if switch('ask'):
		while 1:
			answer = raw_input('OK to execute: ['+command+'] (y or n)? ')
			if answer == 'y' or answer == 'n': break
		if answer=='y':
#			os.system(command)
#			return 1
			return try_to_execute(command)
		else:
			print '['+command+'] not executed.'
			sys.exit()
			return 0
	else:
#		os.system(command)
#		return 1
		return try_to_execute(command)
		
def ask_to_execute_cd(cddir,command):
#	os.system('cd '+cddir)
	i = ask_to_execute('cd '+cddir+'; '+command)
#	os.system('cd ..')
	return i
		
def try_to_execute(command):
#	command2 = string.replace(command,'source ',fncat(os.environ['PACMAN'],'sourcerer.sh '))
	command2 = command
	if verbose: print 'Executing ['+command2+']...'
	i = os.system(command2)
	if i==0: return 1
	else:    return 0

def is_root(): return not os.getuid() 
#	pipe = os.popen('whoami')
#	user = pipe.read()
#	del pipe
#	if user[:4] == 'root' or switch('rootpretend'): return 1
#	else:                  return 0
	
def username(): return pwd.getpwuid(os.getuid())[0]
#	pipe = os.popen('whoami')
#	user = pipe.read()
#	del pipe
#	return (user[:-1])

def put_in_path(root,file,syslocation):
	if is_root():
		if ask_to_execute('cp '+root+'/'+file+' '+syslocation): path = syslocation
		else: path = os.getcwd()+'/'+root
	else:
		path = os.getcwd()+'/'+root
	return (path)

def fncat(a,b):
	if a=='':
		return b
	else:
		if a[len(a)-1]=='/':
			if b=='':
				return (a[:-1])
			else:
				return (a+b)
		else:
			return (a+'/'+b)
			
def tail(str,t):
	found = 0
	if len(str)>= len(t):
		if str[len(str)-len(t):len(str)]==t:
			found = 1
	return found
#
#def yesno(s):
#	if    s == 1: return ('yes')
#	elif  s == 0: return ('no')
#	else:
#		print 'Unexpected argument to yesno.'
#		sys.exit()
#		
def yesdash(s):
	if    s >= 1: return ('yes')
	elif  s == 0: return ('-')
	else:
		print 'Unexpected argument to yesdash.'
		print s
		sys.exit()

def envFile(env,file):
	if os.environ.has_key(env):
		return fncat(os.environ[env],file)
	else:
		print '** Environment variable ['+env+'] is not defined.'
		sys.exit()
		
def envval(env):
	if os.environ.has_key(env): return os.environ[env]
	else: return ''

def substr(sub,base):
	for i in range(len(base)):
		if sub==base[i:i+len(sub)]: return 1
	return 0

def process_on(process):
	psf = os.popen('ps -edalf').readlines()
	l = len(process)
	for line in psf:
		if process == line[len(line)-1-l:len(line)-1]: return 1
	return 0
	
def rpm_installed(rpm_name):
	return (commands.getoutput('rpm -q '+rpm_name)==rpm_name)
	
def yesno(message):
	while 1:
		answer = raw_input(message+' (y or n): ')
		if answer == 'y' or answer == 'yes' or answer == 'n' or answer == 'no': break
	if answer == 'y' or answer == 'yes': return 1
	return 0
	
def rpm_replace(rpm_name):
	if rpm_installed(rpm_name): 
		if switch('force-rpm'):
			return 1
		elif yesno('Package ['+rpm_name+'] is already installed.  Do you want to replace it?'):
			return 1
		else:
			return 0
	else:
		return 0
		
def deWhite(s):
	ss = string.strip(s)
	return ss
